==> zen-cortex-8.1.0.tgz: package/api/helper.js <==
import { selectConfig, selectToken, getZenPort } from "../utils/core";

const HttpResourceWildcard = "*";
const LocalhostWildcard = "::1";

/** Compute web-api complete uniform resource location (URL)
  @param state : redux state tree
  @param endpoint : relative web service endpoint
  @param restricted : true if web-service needs authentication token
*/
export function computeURL(state, endpoint, restricted = false) {
  let url = endpoint;

  if (url.indexOf(HttpResourceWildcard) === 0) {
    //case endpoint is a HTTP served resource (meaning no API call)
    url = url.replace(HttpResourceWildcard, "");
  } else if (url.indexOf(LocalhostWildcard) === 0) {
    //case endpoint is a local HTTP server
    url = url.replace(
      LocalhostWildcard,
      `http://127.0.0.1:${getZenPort(state)}`
    );
  } else {
    //only add API root when necessary
    const apiRoot = selectConfig(state).webAPI;
    url =
      apiRoot && url.indexOf(apiRoot) === -1 ? apiRoot + endpoint : endpoint;
  }

  if (restricted) {
    //add token for restricted API
    url += "/?token=" + selectToken(state);
  }
  return url;
}

//mapping from CRUD method actions to HTTP verbs
export const httpVerbs = {
  CREATE: "POST",
  UPDATE: "PUT",
  PATCH: "PATCH",
  DELETE: "DELETE",
  READ: "GET"
};

/**
 * Helper to build internal error
 * @param {string} message - Error message
 * @param {int} code - Error code
 * @param {int} level - Error level
 * @param {any} content - additional error content
 */
export function makeInternalError(message, code = 400, level = 3, content) {
  return makeError(`${level}-${code}|${message}`, code, content);
}

/**
 * Helper to build standardized error
 * @param {string} message - Error message
 * @param {int} status - HTTP status code
 * @param {any} content - additional error content
 */
export function makeError(message, status = 400, content) {
  let exc = new Error(message);
  exc.number = status;
  if (content) exc.content = content;
  return exc;
}

==> zen-cortex-8.3.0.tgz: package/api/helper.js <==
import { selectConfig, selectToken, getZenPort } from "../utils/core";

const HttpResourceWildcard = "*";
const LocalhostWildcard = "::1";

/**
 * Compute web-api complete uniform resource location (URL)
 * @param {object} state - redux state tree
 * @param {string} endpoint - relative web service endpoint
 * @param {bool} [withToken] - if web-service needs authentication token in query string (default true)
 */
export function computeURL(state, endpoint, withToken = true) {
  let url = endpoint;

  if (url.indexOf(HttpResourceWildcard) === 0) {
    //case endpoint is a HTTP served resource (meaning no API call)
    url = url.replace(HttpResourceWildcard, "");
  } else if (url.indexOf(LocalhostWildcard) === 0) {
    //case endpoint is a local HTTP server
    url = url.replace(
      LocalhostWildcard,
      `http://127.0.0.1:${getZenPort(state)}`
    );
  } else {
    //only add API root when necessary
    const apiRoot = selectConfig(state).webAPI;
    url =
      apiRoot && url.indexOf(apiRoot) === -1 ? apiRoot + endpoint : endpoint;
  }

  if (withToken) {
    //add token for restricted API
    url += "/?token=" + selectToken(state);
  }
  return url;
}

//mapping from CRUD method actions to HTTP verbs
export const httpVerbs = {
  CREATE: "POST",
  UPDATE: "PUT",
  PATCH: "PATCH",
  DELETE: "DELETE",
  READ: "GET",
};

/**
 * Helper to build internal error
 * @param {string} message - Error message
 * @param {int} code - Error code
 * @param {int} level - Error level
 * @param {any} content - additional error content
 */
export function makeInternalError(message, code = 400, level = 3, content) {
  return makeError(`${level}-${code}|${message}`, code, content);
}

/**
 * Helper to build standardized error
 * @param {string} message - Error message
 * @param {int} status - HTTP status code
 * @param {any} content - additional error content
 */
export function makeError(message, status = 400, content) {
  let exc = new Error(message);
  exc.number = status;
  if (content) exc.content = content;
  return exc;
}
